@@ -5,4 +5,7 @@
   name: (command_name (word) @_command)
   argument: (raw_string) @injection.content
  (#match? @_command "^[gnm]?awk$")
- (#set! injection.language "awk"))
\ No newline at end of file
+ (#set! injection.language "awk"))
+
+((regex) @injection.content
+  (#set! injection.language "regex"))
